marktools.get_articulations_attached_to_component
=================================================

.. autofunction:: abjad.tools.marktools.get_articulations_attached_to_component.get_articulations_attached_to_component
   :noindex:
